
class Caculator:
    def __init__(self, isAdd, isSub, isMul, isDiv, isRem):
        self.isAdd = isAdd
        self.isSub = isSub
        self.isMul = isMul
        self.isDiv = isDiv
        self.isRem = isRem

    def adder(self, num1, num2):
        if self.isAdd == True:
            sum = num1 + num2
            return sum
        else:
            raise("Adder is not true.")

    def substraction(self, num1, num2):
        if self.isSub == True:
            return (num1 - num2)
        else:
            raise("Substrator is not true.")

    def multiplication(self, num1, num2):
        if self.isMul == True:
            return (num1 * num2)
        else:
            raise("Multiplication is not true.")

    def division(self, num1, num2):
        if self.isDiv == True:
            try:
                n = num1 / num2
                r = num1 % num2

                if self.isRem == True:
                    return n, r
                else:
                    return n

            except ZeroDivisionError as error:
                print(error)
                return 0
        else:
            raise("Division is not true.")

    def getStatus(self):
        return {
            "add": self.isAdd,
            "sub": self.isSub,
            "mul": self.isMul,
            "div": self.isDiv,
            "rem": self.isRem
        }




from setuptools import setup, find_packages

version = "0.0.1"

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name            = "khleepkg03",
    version         = version,
    description     = "SSL-Seminar-test repository:: Topic - Package Test and Deployment",
    long_description= long_description,
    long_description_content_type="text/markdown",
    author          = "Keon-Hee Lee",
    author_email    = "beta1360@naver.com",
    url             = "https://github.com/KeonHeeLee/ssl-lab-test",
    install_requires= [],
    packages        = find_packages(exclude=['test*']),
    keywords        = ['Test', 'TDD', 'Deployment', 'Seminar'],
    python_requires = '>=3',
    zip_safe        = False,
    license         = 'MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'License :: OSI Approved :: MIT License'
    ]
)